@@ -1,4 +1,6 @@
-'use strict';
+// Custom inspect property name / symbol.
+var inspect = Buffer ? require('util').inspect.custom || 'inspect' : 'inspect';
+
 /**
  * A class representation of the BSON Symbol type.
  *
@@ -33,7 +35,7 @@ Symbol.prototype.toString = function() {
 /**
  * @ignore
  */
-Symbol.prototype.inspect = function() {
+Symbol.prototype[inspect] = function() {
   return this.value;
 };
 
